is_panic_stderr_suppressed

Function is_panic_stderr_suppressed 

pub fn is_panic_stderr_suppressed() -> bool
Returns true while a SuppressPanicStderr guard is alive on this thread.

Used by the custom panic hook installed in logger::initialize() to avoid printing anything when a panic is caught by std::panic::catch_unwind.